@@ -1,11 +1,10 @@
 import json
+
 import py
-import textwrap
+import requests
 
 issues_url = "https://api.github.com/repos/pytest-dev/pytest/issues"
 
-import requests
-
 
 def get_issues():
     issues = []
@@ -16,16 +15,16 @@ def get_issues():
         data = r.json()
         if r.status_code == 403:
             # API request limit exceeded
-            print(data['message'])
+            print(data["message"])
             exit(1)
         issues.extend(data)
 
         # Look for next page
-        links = requests.utils.parse_header_links(r.headers['Link'])
+        links = requests.utils.parse_header_links(r.headers["Link"])
         another_page = False
         for link in links:
-            if link['rel'] == 'next':
-                url = link['url']
+            if link["rel"] == "next":
+                url = link["url"]
                 another_page = True
         if not another_page:
             return issues
@@ -46,17 +45,17 @@ def main(args):
 
 
 def _get_kind(issue):
-    labels = [l['name'] for l in issue['labels']]
-    for key in ('bug', 'enhancement', 'proposal'):
+    labels = [l["name"] for l in issue["labels"]]
+    for key in ("bug", "enhancement", "proposal"):
         if key in labels:
             return key
-    return 'issue'
+    return "issue"
 
 
 def report(issues):
     for issue in issues:
         title = issue["title"]
-        body = issue["body"]
+        # body = issue["body"]
         kind = _get_kind(issue)
         status = issue["state"]
         number = issue["number"]
@@ -64,21 +63,23 @@ def report(issues):
         print("----")
         print(status, kind, link)
         print(title)
-        #print()
-        #lines = body.split("\n")
-        #print ("\n".join(lines[:3]))
-        #if len(lines) > 3 or len(body) > 240:
+        # print()
+        # lines = body.split("\n")
+        # print ("\n".join(lines[:3]))
+        # if len(lines) > 3 or len(body) > 240:
         #    print ("...")
     print("\n\nFound %s open issues" % len(issues))
 
 
 if __name__ == "__main__":
     import argparse
+
     parser = argparse.ArgumentParser("process bitbucket issues")
-    parser.add_argument("--refresh", action="store_true",
-                        help="invalidate cache, refresh issues")
-    parser.add_argument("--cache", action="store", default="issues.json",
-                        help="cache file")
+    parser.add_argument(
+        "--refresh", action="store_true", help="invalidate cache, refresh issues"
+    )
+    parser.add_argument(
+        "--cache", action="store", default="issues.json", help="cache file"
+    )
     args = parser.parse_args()
     main(args)
-
