@@ -20,7 +20,7 @@ from _pytest.terminal import build_summary_stats_line
 from _pytest.terminal import getreportopt
 from _pytest.terminal import repr_pythonversion
 from _pytest.terminal import TerminalReporter
-
+from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 
 DistInfo = collections.namedtuple("DistInfo", ["project_name", "version"])
 
@@ -602,7 +602,7 @@ class TestTerminalFunctional(object):
                 yield check, 0
         """
         )
-        result = testdir.runpytest(p1, "-v")
+        result = testdir.runpytest(p1, "-v", SHOW_PYTEST_WARNINGS_ARG)
         result.stdout.fnmatch_lines(
             [
                 "*test_verbose_reporting.py::test_fail *FAIL*",
@@ -616,7 +616,7 @@ class TestTerminalFunctional(object):
         if not pytestconfig.pluginmanager.get_plugin("xdist"):
             pytest.skip("xdist plugin not installed")
 
-        result = testdir.runpytest(p1, "-v", "-n 1")
+        result = testdir.runpytest(p1, "-v", "-n 1", SHOW_PYTEST_WARNINGS_ARG)
         result.stdout.fnmatch_lines(["*FAIL*test_verbose_reporting.py::test_fail*"])
         assert result.ret == 1
 
