@@ -9,6 +9,7 @@ import six
 import pytest
 from _pytest import pathlib
 from _pytest.pathlib import Path
+from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 
 
 def test_tmpdir_fixture(testdir):
@@ -67,7 +68,7 @@ def test_basetemp(testdir):
             pytest.ensuretemp("hello")
     """
     )
-    result = testdir.runpytest(p, "--basetemp=%s" % mytemp)
+    result = testdir.runpytest(p, "--basetemp=%s" % mytemp, SHOW_PYTEST_WARNINGS_ARG)
     assert result.ret == 0
     assert mytemp.join("hello").check()
 
